class MeQrMetaBox {
    _errors = {
        postId: 'Post id not found.',
        qrImg: 'Qr image element not found in DOM structure.',
        downloadBtn: 'Download btn not found.',
        shortcodeBox: 'Shortcode box not found in DOM structure.',
        shortcodeInput: 'Shortcode input not found.',
        shortcodeBtn: 'Shortcode copy btn not found.',
        qrRequest: 'Request error for receiving Qr-codes.',
    };

    _qrCodes = {
        qrPng: '',
        qrSvg: '',
    }

    constructor(configs) {
        this._configs = {
            renderBtnSelector: '.me-qr-wc-render-btn',
            renderBoxSelector: '.me-qr-wc-render-box',
            qrBodyBoxSelector: '.me-qr-wc-body',
            radioFormatBoxSelector: 'input[name="me_qr_wc_choice_qr_format"]',
            qrImgSelector: '.me-qr-wc-img',
            downloadBtnSelector: '.me-qr-wc-download-btn',
            errorModule: (new ErrorModule()),
            loadingModule: (new LoadingModule()),
            callbackSuccessQrRequest: null,
            callbackChangeFormat: null,
            ...configs
        };
    }

    handel() {
        const self = this;
        if ( postId === undefined ) {
            throw new Error(self._errors.postId);
        }

        $(document.body).on('click', this._configs.renderBtnSelector, function () {
            const renderBox = $(self._configs.renderBoxSelector);

            renderBox.addClass('me-qr-d-none');
            self._configs.loadingModule.show();
            self._sendRequestQrs();
        });
    }

    _sendRequestQrs() {
        const self = this;

        $.ajax({
            url: document.location.origin + "/wp-json/me-qr/api/get/all-qr",
            type: 'POST',
            data: {
                postId: postId,
            },
            success: function (response) {
                const qrPng = response.qr_codes.qr_png;
                const qrSvg = response.qr_codes.qr_svg;
                if (!qrPng || !qrSvg) {
                    throw new Error(self._errors.qrRequest);
                }

                self._qrCodes.qrPng = qrPng;
                self._qrCodes.qrSvg = qrSvg;

                const renderBox = $(self._configs.renderBoxSelector),
                    qrBodyBox = $(self._configs.qrBodyBoxSelector)
                ;
                renderBox.remove();
                self._configs.loadingModule.remove();
                self._replaceQrImg(self._qrCodes.qrPng);
                self._replaceQrForDownloadBtn(self._qrCodes.qrPng);
                qrBodyBox.removeClass('me-qr-d-none');
                self._handelRadioBoxTrigger();

                if ( self._configs.callbackSuccessQrRequest ) {
                    self._configs.callbackSuccessQrRequest(self._qrCodes);
                }
            },
            error: function (response) {
                self._configs.errorModule.show();
                self._configs.loadingModule.remove();
            },
        });
    }

    _handelRadioBoxTrigger() {
        const self = this;

        $(document.body).on('change', this._configs.radioFormatBoxSelector, function () {
            if ($(this).val() === 'svg') {
                self._replaceQrImg(self._qrCodes.qrSvg);
                self._replaceQrForDownloadBtn(self._qrCodes.qrSvg);
                if (self._configs.callbackChangeFormat) {
                    self._configs.callbackChangeFormat('svg');
                }
                return;
            }

            self._replaceQrImg(self._qrCodes.qrPng);
            self._replaceQrForDownloadBtn(self._qrCodes.qrPng);
            if (self._configs.callbackChangeFormat) {
                self._configs.callbackChangeFormat('png');
            }
        });
    }

    _replaceQrImg(qrString) {
        const img = $(this._configs.qrImgSelector);
        if (!img.length) {
            throw new Error( this._errors.qrImg );
        }

        img.attr('src', qrString);
    }

    _replaceQrForDownloadBtn(qrString) {
        const downloadBtn = $(this._configs.downloadBtnSelector);
        if (downloadBtn.length === 0) {
            throw new Error(this._errors.downloadBtn);
        }

        downloadBtn.attr('href', qrString);
    }
}
