<?php

namespace Me_Qr\Foundation;

use Me_Qr\Controller\Api\QrCodeLinkController;
use Me_Qr\Services\ErrorHandler\ErrorHandlerService;
use Me_Qr\Services\MeQrCoreService;
use Me_Qr\Services\MeQrDeactivationInstallationService;
use Me_Qr\Services\MeQrPluginInstallationService;
use Throwable;

class MeQrPluginExecute
{
    private Container $container;
    private ErrorHandlerService $errorHandlerService;

    public function __construct() {
        $this->container = new Container();
        $this->errorHandlerService = $this->container->get( ErrorHandlerService::class );
    }

    public function execute(): void
    {
        $this->installation();
        $this->deactivation();
        $this->core();
        $this->api();
    }

    public function installation(): void
    {
        register_activation_hook( MQ_FILE_PATH, function() {
            try {
                /** @noinspection NullPointerExceptionInspection */
                $this->container->get( MeQrPluginInstallationService::class )->handle();
            } catch (Throwable $e) {
                $this->errorHandlerService->handleException($e);
            }
        } );
    }

    public function deactivation(): void
    {
        register_deactivation_hook( MQ_FILE_PATH, function() {
            try {
                /** @noinspection NullPointerExceptionInspection */
                $this->container->get( MeQrDeactivationInstallationService::class )->handle();
            } catch (Throwable $e) {
                $this->errorHandlerService->handleException($e);
            }
        } );
    }

    public function core(): void
    {
        add_action( 'init', function() {
            try {
                /** @noinspection NullPointerExceptionInspection */
                $this->container->get( MeQrCoreService::class )->execute();
            } catch (Throwable $e) {
                $this->errorHandlerService->handleException($e);
            }
        });
    }

    public function api(): void
    {
        add_action( 'rest_api_init', function() {
            try {
                /** @noinspection NullPointerExceptionInspection */
                $this->container->get( QrCodeLinkController::class )->register_routes();
            } catch (Throwable $e) {
                $this->errorHandlerService->handleException($e);
            }
        } );
    }
}
