<?php

namespace Me_Qr\Requests;

use JsonException;
use Me_Qr\Exceptions\QrCode\QrCodeExceptionInterface;
use Me_Qr\Exceptions\QrCode\QrCodeNotFoundException;
use Me_Qr\Exceptions\QrCode\QrCodeRequestDataException;
use Throwable;

class QrRequests
{
    /**
     * @throws QrCodeExceptionInterface
     */
    public function createQrRequest(array $requestData): array
    {
        return $this->createRequest(ME_QR_GET_QR_REQUEST_URL, $requestData);
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function createAllQrRequest(array $requestData): array
    {
        return $this->createRequest(ME_QR_GET_ALL_QR_REQUEST_URL, $requestData);
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function createRequest(string $requestUrl, array $requestData): array
    {
        try {
            $jsonRequestData = json_encode($requestData, JSON_THROW_ON_ERROR);
        } catch (Throwable $e) {
            throw new QrCodeRequestDataException("Json data encoding error during qr code request");
        }

        $response = wp_remote_post($requestUrl, [
            'headers' => [
                'content-type' => 'application/json',
            ],
            'body' => $jsonRequestData,
            'timeout' => ME_QR_REQUEST_TIMEOUT,
        ]);

        $responseCode = wp_remote_retrieve_response_code($response);
        $responseBody = wp_remote_retrieve_body($response);
        if ( $responseCode !== 200 ) {
            throw new QrCodeNotFoundException("QR code generation error. Error content: $responseBody.");
        }

        try {
            $responseArr = json_decode($responseBody, true, 512, JSON_THROW_ON_ERROR);
            if ( !is_array($responseArr) ) {
                return [];
            }

            return $responseArr;
        } catch (JsonException $e) {
            throw new QrCodeNotFoundException("Received data decoding error. Error message: $responseBody.");
        }
    }
}