<?php

namespace Me_Qr\Requests;

use JsonException;
use Me_Qr\Exceptions\RegistrationStartException;
use Me_Qr\Services\ErrorHandler\ErrorHandlerService;

class UserRequests
{
    private ErrorHandlerService $errorHandlerService;

    public function __construct(
        ErrorHandlerService $errorHandlerService
    ) {
        $this->errorHandlerService = $errorHandlerService;
    }

    /**
     * @throws RegistrationStartException
     */
    public function createUserRequest(array $data): array
    {
        $response = wp_remote_post(ME_QR_USER_CREATION_URL, [
            'body' => $data,
            'timeout' => ME_QR_REQUEST_TIMEOUT,
        ]);

        $responseCode = wp_remote_retrieve_response_code($response);
        $responseBody = wp_remote_retrieve_body($response);
        if ( $responseCode !== 200 ) {
            throw new RegistrationStartException(
                "Unknown error registering owner of Qr-codes. Error content: $responseBody."
            );
        }

        try {
            $responseArr = json_decode($responseBody, true, 512, JSON_THROW_ON_ERROR);
            if ( !is_array($responseArr) ) {
                return [];
            }

            return $responseArr;
        } catch (JsonException $e) {
            $this->errorHandlerService->handleException($e, false, true, true);
            throw new RegistrationStartException(
                "Received data decoding error registration request. Error message: $responseBody."
            );
        }
    }
}
