<?php

namespace Me_Qr\Services\ErrorHandler;

use Me_Qr\Services\Loggers\TelegramLog\TelegramLogHandler;
use Me_Qr\Services\Template\TemplateService;
use Me_Qr\Services\Loggers\FileLog\FileLogHandler;
use Me_Qr\Services\Url\DevService;
use Throwable;

class ErrorHandlerService
{
    private TelegramLogHandler $telegramLogHandler;
    private RecurringErrorFuse $recurringErrorFuse;
    private FileLogHandler $fileLogHandler;
    private TemplateService $templateService;

    public function __construct(
        TelegramLogHandler $telegramLogHandler,
        RecurringErrorFuse $recurringErrorFuse,
        FileLogHandler $fileLogHandler,
        TemplateService $templateService
    ) {
        $this->telegramLogHandler = $telegramLogHandler;
        $this->recurringErrorFuse = $recurringErrorFuse;
        $this->fileLogHandler = $fileLogHandler;
        $this->templateService = $templateService;
    }

    public function handleException(
        Throwable $exception,
        bool $isWriteLogs = true,
        bool $isSendToTgLog = true,
        bool $isShowInAdmin = false
    ): void {
        if ( $isWriteLogs ) {
            $this->writeExceptionToLogs($exception);
        }
        if ( $isSendToTgLog ) {
            $this->sendExceptionToTelegramLog($exception);
        }
        if ( $isShowInAdmin ) {
            $this->showAdminException($exception);
        }
    }

    public function handleError(
        string $message,
        bool $isShowInAdmin = true,
        bool $isWriteLogs = true
    ): void {
        if ( $isShowInAdmin ) {
            $this->showAdminError($message);
        }
        if ( $isWriteLogs ) {
            $this->writeErrorToLogs($message);
        }
    }

    public function showAdminException(Throwable $exception): void
    {
        $this->showAdminError($exception->getMessage());
    }

    public function showAdminError(string $message): void
    {
        if ( ME_QR_IS_SHOW_ADMIN_NOTIFICATION !== true ) {
            return;
        }

        add_action( 'admin_notices', function() use ($message) {
            $this->templateService->include('admin/errors/me-qr-admin-error', [
                'message' => $message,
            ]);
        } );
    }

    public function writeExceptionToLogs(Throwable $exception): void
    {
        if ( ME_QR_IS_WRITING_PLUGIN_LOGS !== true ) {
            return;
        }

        $this->fileLogHandler->exception($exception);
    }

    public function writeErrorToLogs(string $message): void
    {
        if ( ME_QR_IS_WRITING_PLUGIN_LOGS !== true ) {
            return;
        }

        $this->fileLogHandler->error($message);
    }

    public function sendExceptionToTelegramLog(Throwable $exception): void
    {
        if (
            ME_QR_IS_SENDING_TG_LOGS === true &&
            $this->recurringErrorFuse->isValidException($exception) &&
            !DevService::isDevMode()
        ) {
            $this->telegramLogHandler->exception($exception);
        }
    }
}
