<?php

namespace Me_Qr\Services\Gutenberg;

use Me_Qr\Foundation\MeQrBaseFunctions;
use Me_Qr\Services\QrSave\QrFileManager;
use Me_Qr\Services\Url\UrlService;

class MeQrGutenbergService
{
    private QrFileManager $qrFileManager;

    public function __construct(QrFileManager $qrFileManager)
    {
        $this->qrFileManager = $qrFileManager;
    }

    public function registerQrMetaBox(): void
    {
        if ( UrlService::is_gutenberg_page() ) {
            $this->register_sidebar_styles();
            $this->register_sidebar_scripts();
        }
    }

    private function register_sidebar_styles(): void
    {
        add_action('admin_enqueue_scripts', function() {
            wp_enqueue_style('me_qr_gutenberg_block_style', MeQrBaseFunctions::getCssUrl(
                'admin/gutenberg/qr-meta-box'
            ));
        });
    }

    private function register_sidebar_scripts(): void
    {
        add_action('enqueue_block_editor_assets', function() {
            wp_enqueue_script('me_qr_npm_script', MeQrBaseFunctions::build_url('frontend/build/index.js'),
                [ 'wp-edit-post' ]
            );

            $currentPostId = get_the_ID();
            $isQrsExists = (int) $this->qrFileManager->isQrsExists($currentPostId);

            wp_add_inline_script('me_qr_npm_script', "let isQrsExists = $isQrsExists;", 'before');
        });
    }
}
