<?php

namespace Me_Qr\Services\Loggers\TelegramLog;

use Me_Qr\Requests\TelegramLogRequest;
use Throwable;

class TelegramLogHandler
{
    private TelegramErrorLogService $errorLogService;
    private TelegramInfoLogService $infoLogService;
    private TelegramLogRequest $telegramLogRequest;

    public function __construct(
        TelegramErrorLogService $errorLogService,
        TelegramInfoLogService $infoLogService,
        TelegramLogRequest $telegramLogRequest
    ) {
        $this->errorLogService = $errorLogService;
        $this->infoLogService = $infoLogService;
        $this->telegramLogRequest = $telegramLogRequest;
    }

    public function error(string $message): void
    {
        $this->telegramLogRequest->sendMessage(
            $this->errorLogService->createByMessage($message)
        );
    }

    public function exception(Throwable $exception): void
    {
        $this->telegramLogRequest->sendMessage(
            $this->errorLogService->createByException($exception)
        );
    }

    public function info(string $message): void
    {
        $this->infoLogService->createByMessage($message);
    }
}