<?php

namespace Me_Qr\Services;

use Me_Qr\Foundation\MeQrBaseFunctions;
use Me_Qr\Services\Gutenberg\MeQrGutenbergService;
use Me_Qr\Services\QrSave\QrUpdateHandler;
use Me_Qr\Services\Shortcodes\ShortcodeService;
use Me_Qr\Services\Woocommerce\MeQrWoocommerceService;

class MeQrCoreService
{
    private ShortcodeService $shortcodeService;
    private MeQrGutenbergService $meQrGutenbergService;
    private MeQrWoocommerceService $meQrWoocommerceService;
    private QrUpdateHandler $qrUpdateHandler;

    public function __construct(
        ShortcodeService $shortcodeService,
        MeQrGutenbergService $meQrGutenbergService,
        MeQrWoocommerceService $meQrWoocommerceService,
        QrUpdateHandler $qrUpdateHandler
    ) {
        $this->shortcodeService = $shortcodeService;
        $this->meQrGutenbergService = $meQrGutenbergService;
        $this->meQrWoocommerceService = $meQrWoocommerceService;
        $this->qrUpdateHandler = $qrUpdateHandler;
    }

    public function execute(): void
    {
        $this->registerGlobalStyles();
        $this->registerGlobalScripts();
        $this->shortcodeService->registerShortcodes();
        $this->meQrGutenbergService->registerQrMetaBox();
        $this->meQrWoocommerceService->registerProductEditorQrMetaBox();
        $this->qrUpdateHandler->registerPostUpdateHook();
    }

    public function registerGlobalStyles(): void
    {
        // Place to register global styles

        add_action('admin_enqueue_scripts', function() {
            wp_enqueue_style('me_qr_admin_global_colors', MeQrBaseFunctions::getCssUrl('me-qr-colors' ));
        });
        add_action('wp_enqueue_scripts', function() {
            wp_enqueue_style('me_qr_front_global_colors', MeQrBaseFunctions::getCssUrl('me-qr-colors' ));
        });
        add_action('admin_enqueue_scripts', function() {
            wp_enqueue_style('me_qr_admin_base_style', MeQrBaseFunctions::getCssUrl('me-qr-base' ));
        });
        add_action('enqueue_scripts', function() {
            wp_enqueue_style('me_qr_front_base_style', MeQrBaseFunctions::getCssUrl('me-qr-base' ));
        });
    }

    public function registerGlobalScripts(): void
    {
        // Place to register global scripts
    }
}
