<?php

namespace Me_Qr\Services\QrProvider;

use Me_Qr\Exceptions\QrCode\QrCodeExceptionInterface;
use Me_Qr\Services\QrProvider\DTO\AllQrFormatProviderDTO;
use Me_Qr\Services\QrProvider\DTO\AllQrFormatProviderDTOBuilder;
use Me_Qr\Services\QrProvider\DTO\QrProviderDTO;
use Me_Qr\Services\QrProvider\DTO\QrProviderDTOBuilder;
use Me_Qr\Services\QrRequest\QrRequestService;
use Me_Qr\Services\QrSave\QrFileManager;

class QrProvider
{
    private QrRequestService $qrRequestService;
    private QrFileManager $qrFileManager;

    public function __construct(
        QrRequestService $qrRequestService,
        QrFileManager $qrFileManager
    ) {
        $this->qrRequestService = $qrRequestService;
        $this->qrFileManager = $qrFileManager;
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function getQr(int $postId, string $link, string $format): QrProviderDTO
    {
        if ( !$this->qrFileManager->isQrExists($postId, $format) ) {
            $requestedQr = $this->qrRequestService->getQrLink($link, $format);
            $this->qrFileManager->saveQrByPostId($requestedQr, $postId, $format);
        }

        $qrCode = $this->qrFileManager->getQrByPostId($postId, $format);
        return QrProviderDTOBuilder::build($qrCode, $format);
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function getAllQrFormat(int $postId, string $link): AllQrFormatProviderDTO
    {
        $isExistsQrPng = $this->qrFileManager->isQrExists($postId, ME_QR_PNG_FORMAT);
        $isExistsQrSvg = $this->qrFileManager->isQrExists($postId, ME_QR_SVG_FORMAT);
        if ( !$isExistsQrPng || !$isExistsQrSvg ) {
            $requestedQrDTO = $this->qrRequestService->getAllQrLink($link);
            $this->qrFileManager->saveQrByPostId($requestedQrDTO->getPngQr(), $postId, ME_QR_PNG_FORMAT);
            $this->qrFileManager->saveQrByPostId($requestedQrDTO->getSvgQr(), $postId, ME_QR_SVG_FORMAT);
        }

        $pngQrLink = $this->qrFileManager->getQrByPostId($postId, ME_QR_PNG_FORMAT);
        $svgQrLink = $this->qrFileManager->getQrByPostId($postId, ME_QR_SVG_FORMAT);
        $qrPngProviderDTO = QrProviderDTOBuilder::build($pngQrLink, ME_QR_PNG_FORMAT);
        $qrSvgProviderDTO = QrProviderDTOBuilder::build($svgQrLink, ME_QR_SVG_FORMAT);

        return AllQrFormatProviderDTOBuilder::build($qrPngProviderDTO, $qrSvgProviderDTO);
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function updateAllQrFormatByPostId(int $postId, string $link): AllQrFormatProviderDTO
    {
        $requestedQrDTO = $this->qrRequestService->getAllQrLink($link);
        $this->qrFileManager->deleteQrByPostId($postId, ME_QR_PNG_FORMAT);
        $this->qrFileManager->deleteQrByPostId($postId, ME_QR_SVG_FORMAT);
        $this->qrFileManager->saveQrByPostId($requestedQrDTO->getPngQr(), $postId, ME_QR_PNG_FORMAT);
        $this->qrFileManager->saveQrByPostId($requestedQrDTO->getSvgQr(), $postId, ME_QR_SVG_FORMAT);

        $qrPngProviderDTO = QrProviderDTOBuilder::build($requestedQrDTO->getPngQr(), ME_QR_PNG_FORMAT);
        $qrSvgProviderDTO = QrProviderDTOBuilder::build($requestedQrDTO->getSvgQr(), ME_QR_SVG_FORMAT);

        return AllQrFormatProviderDTOBuilder::build($qrPngProviderDTO, $qrSvgProviderDTO);
    }
}
