<?php

namespace Me_Qr\Services\QrRequest;

use Me_Qr\Exceptions\QrCode\QrCodeExceptionInterface;
use Me_Qr\Exceptions\QrCode\QrCodeNotFoundException;
use Me_Qr\Requests\QrRequests;
use Me_Qr\Services\QrRequest\DTO\AllQrFormatRequestDTO;
use Me_Qr\Services\QrRequest\DTO\AllQrFormatRequestDTOBuilder;
use Me_Qr\Services\UserRegistration\UserQrTokenService;

class QrRequestService
{
    private QrRequests $qrRequests;

    public function __construct(
        QrRequests $qrRequests
    ) {
        $this->qrRequests = $qrRequests;
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function getQrLink(string $link, string $format): string
    {
        $qrToken = UserQrTokenService::get();
        if ( !$qrToken ) {
            throw new QrCodeNotFoundException('User token for QR code request not created. Restart plugin.');
        }

        $requestData = [
            'token' => $qrToken,
            'link' => $link,
            'format' => $format,
        ];

        $responseData = $this->qrRequests->createQrRequest($requestData);
        $qrCode = $responseData['qr_code'] ?? null;
        if ( !$qrCode ) {
            throw new QrCodeNotFoundException('Qr code not received');
        }

        return $qrCode;
    }

    /**
     * @throws QrCodeExceptionInterface
     */
    public function getAllQrLink(string $link): AllQrFormatRequestDTO
    {
        $qrToken = UserQrTokenService::get();
        if ( !$qrToken ) {
            throw new QrCodeNotFoundException('User token for QR code request not created. Restart plugin.');
        }

        $requestData = [
            'token' => $qrToken,
            'link' => $link,
        ];

        $responseData = $this->qrRequests->createAllQrRequest($requestData);
        $qrCodes = $responseData['qr_codes'] ?? null;
        if ( !$qrCodes ) {
            throw new QrCodeNotFoundException('Qr codes not received');
        }

        $pngQr = $qrCodes['qr_png'] ?? null;
        if (!$pngQr) {
            throw new QrCodeNotFoundException('Mandatory qr code in png format not received');
        }

        $svgQr = $qrCodes['qr_svg'] ?? null;
        if (!$svgQr) {
            throw new QrCodeNotFoundException('Mandatory qr code in png format not received');
        }

        return AllQrFormatRequestDTOBuilder::build($pngQr, $svgQr);
    }
}
