<?php

namespace Me_Qr\Services\Shortcodes;

use Me_Qr\Services\ErrorHandler\ErrorHandlerService;
use Me_Qr\Services\QrProvider\QrProvider;
use Me_Qr\Services\Shortcodes\Exceptions\ShortcodeDataException;
use Me_Qr\Services\Shortcodes\QrPageShortcode\DTO\ShortcodeDataDTOBuilder;
use Me_Qr\Services\Template\TemplateService;
use Me_Qr\Services\Validation\MeQrValidator;
use Throwable;

class ShortcodeService
{
    private QrProvider $qrProvider;
    private MeQrValidator $meQrValidator;
    private ErrorHandlerService $errorHandlerService;
    private TemplateService $templateService;

    public function __construct(
        QrProvider $qrProvider,
        MeQrValidator $meQrValidator,
        ErrorHandlerService $errorHandlerService,
        TemplateService $templateService
    ) {
        $this->qrProvider = $qrProvider;
        $this->meQrValidator = $meQrValidator;
        $this->errorHandlerService = $errorHandlerService;
        $this->templateService = $templateService;
    }

    public function registerShortcodes(): void
    {
        add_shortcode( 'me_qr_block', [$this, 'qrFrontShortcode'] );
    }

    /**
     * @Param string $format optional
     *
     * Shortcode for adding a qr-code to the external part of the site
     */
    public function qrFrontShortcode($attrs): ?string
    {
        try {
            $shortcodeDTO = ShortcodeDataDTOBuilder::buildByOptionArray($attrs);
            $exceptions = $this->meQrValidator->validate($shortcodeDTO);
            if ( $exceptions->isException() ) {
                $this->meQrValidator->handelExceptionList($exceptions);
                return null;
            }

            $postLink = get_permalink( $shortcodeDTO->getPostId() );
            if ( !$postLink ) {
                throw new ShortcodeDataException('No post found for the specified post id');
            }
            $qrProviderDTO = $this->qrProvider->getQr(
                $shortcodeDTO->getPostId(), $postLink, $shortcodeDTO->getFormat()
            );
        } catch (ShortcodeDataException $e) {
            $this->errorHandlerService->writeExceptionToLogs($e);
            return null;
        } catch (Throwable $e) {
            $this->errorHandlerService->handleException($e);
            return null;
        }

        return $this->templateService->getIncludeString('front/me-qr-shortcode-qr-template', [
            'qrCodeDTO' => $qrProviderDTO,
            'shortcodeDTO' => $shortcodeDTO,
        ]);
    }
}
