<?php

namespace Me_Qr\Services\Template;

use Me_Qr\Foundation\MeQrBaseFunctions;
use Me_Qr\Services\Loggers\FileLog\FileLogHandler;
use Throwable;

class TemplateService
{
    private FileLogHandler $fileLogHandler;

    public function __construct(FileLogHandler $fileLogHandler)
    {
        $this->fileLogHandler = $fileLogHandler;
    }

    public function include(string $path, array $params = []): void
    {
        echo ( $this->getTemplateContent($path, $params) );
    }

    public function getIncludeString(string $path, array $params = []): string
    {
        return $this->getTemplateContent($path, $params);
    }

    private function getTemplateContent(string $path, array $params = []): string
    {
        try {
            ob_start();
            $templateFunction = include( MeQrBaseFunctions::getTemplateUrl($path) );
            $params['templatePath'] = $path;
            $templateFunction(new TemplateParams($params));

            return ob_get_clean();
        } catch (Throwable $e) {
            $this->fileLogHandler->exception($e);

            return '';
        }
    }
}
