<?php

namespace Me_Qr\Services\UserRegistration;

use Me_Qr\Exceptions\AdminUndefinedException;
use Me_Qr\Exceptions\RegistrationStartException;
use Me_Qr\Repository\UserEntityRepository;
use Me_Qr\Requests\UserRequests;

class UserRequestsService
{
    private UserEntityRepository $userEntityRepository;
    private UserRequests $userRequests;

    public function __construct(
        UserEntityRepository $userEntityRepository,
        UserRequests $userRequests
    ) {
        $this->userEntityRepository = $userEntityRepository;
        $this->userRequests = $userRequests;
    }

    /**
     * @throws AdminUndefinedException
     * @throws RegistrationStartException
     */
    public function registerQrUser(): string
    {
        $adminEmail = get_option('admin_email');
        $user = $this->userEntityRepository->findUserByEmail($adminEmail);
        if (!$user) {
            throw new AdminUndefinedException();
        }

        $requestData = [
            'request_token' => UserTokenService::get($user),
            'user_id' => $user->getId(),
            'user_email' => $user->getUserEmail(),
            'user_registration_date' => $user->getUserRegistered(),
        ];

        $response = $this->userRequests->createUserRequest($requestData);
        $token = $response['token'] ?? null;
        if ( !$token ) {
            throw new RegistrationStartException("Token for receiving qr codes is not registered.");
        }

        return $token;
    }
}
