<?php

namespace Me_Qr\Services\Validation\Assert;

use Me_Qr\Foundation\Container;
use Me_Qr\Services\ErrorHandler\ErrorHandlerService;
use Me_Qr\Services\Validation\Exceptions\ValidationSystemError;
use Me_Qr\Services\Validation\ValidationExceptionList;
use ReflectionClass;
use ReflectionException;
use ReflectionProperty;
use Throwable;

class AssertService
{
    private ErrorHandlerService $errorHandlerService;

    public function __construct(ErrorHandlerService $errorHandlerService)
    {
        $this->errorHandlerService = $errorHandlerService;
    }

    public function getAllAnnotationPropertiesByObject(object $object): array
    {
        $arrayRes = [];
        try {
            $ref = new ReflectionClass($object);

            foreach ($ref->getProperties() as $property) {
                $annotation = $property->getDocComment();
                if ( !$annotation || !strripos($annotation, AssertConfigs::ASSERT_ANNOTATION_TITLE) ) {
                    continue;
                }

                $arrayRes[] = $property;
            }

            return $arrayRes;
        } catch (ReflectionException $e) {
            $this->errorHandlerService->writeExceptionToLogs($e);
            return $arrayRes;
        }
    }

    /**
     * @param ReflectionProperty[] $properties
     */
    public function validateProperties(array $properties, object $object): ValidationExceptionList
    {
        $container = new Container();
        $validationList = new ValidationExceptionList();

        try {
            foreach ($properties as $property) {
                foreach (AssertConfigs::ASSERT_TYPES as $key => $type) {
                    if ( $this->isAssertTypeProperty($property, $key) ) {
                        $moduleClass = $container->get( $type );
                        $exception = $moduleClass->validate( $property, $object );
                        if ( $exception ) {
                            $validationList->addException($exception);
                        }
                    }
                }
            }
        } catch (Throwable $e) {
            $this->errorHandlerService->writeExceptionToLogs($e);
            $validationList->addException(new ValidationSystemError());
        }

        return $validationList;
    }

    public function isAssertTypeProperty(ReflectionProperty $property, string $validationType): bool
    {
        $validationTypeTitle = AssertConfigs::ASSERT_ANNOTATION_TITLE . $validationType;
        return strripos($property->getDocComment(), $validationTypeTitle) !== false;
    }
}
