<?php

namespace Me_Qr\Services\Validation\Assert\Types\QrCode;

use Me_Qr\Services\Validation\Exceptions\ValidationExceptionInterface;
use Me_Qr\Services\Validation\Assert\Types\AbstractValidationType;

class QrFormatType extends AbstractValidationType
{
    public const MODULE_TITLE = 'QrFormat';

    public const VALID_FORMATS_PROPERTY = 'validFormats';
    public const ERROR_MESSAGE_PROPERTY = 'errorMessage';

    private array $validFormats = ME_QR_VALID_QR_FORMATS;

    protected ?string $errorMessage = 'The qr code format does not match the available formats.';

    /**
     * @throws ValidationExceptionInterface
     */
    public function declare(array $propertyParams): void
    {
        $validFormats = $propertyParams[self::VALID_FORMATS_PROPERTY] ?? null;
        if ( $validFormats && is_array($validFormats) ) {
            $this->validFormats = $validFormats;
        }
    }

    public function isValid(): bool
    {
        if ( !$this->value ) {
            return false;
        }

        $clearFormat = sanitize_text_field($this->value);
        if ( !$clearFormat ) {
            return false;
        }

        $isValidFormats = in_array($clearFormat, $this->validFormats, true);
        if ( !$isValidFormats ) {
            return false;
        }

        return true;
    }
}
