<?php

namespace Me_Qr\Services\Validation\Assert\Types;

use Me_Qr\Services\Validation\Exceptions\ValidationExceptionInterface;
use ReflectionProperty;

interface ValidationTypeInterface
{
    /**
     * Sets the name of the current validation type
     */
    public const MODULE_TITLE = 'ValidationTypeName';

    /**
     * Calls the declare method, and isValid. Defined in an abstract class. Can be overridden
     *
     * @throws ValidationExceptionInterface
     */
    public function validate(ReflectionProperty $property, object $object): ?ValidationExceptionInterface;

    /**
     * Declares properties of the validation type annotation. Defined in the type class.
     *
     * @throws ValidationExceptionInterface
     */
    public function declare(array $propertyParams): void;

    /**
     * Validation type business logic
    */
    public function isValid(): bool;
}
