<?php

namespace Me_Qr\Services\Validation;

use Me_Qr\Services\ErrorHandler\ErrorHandlerService;
use Me_Qr\Services\Validation\Assert\AssertService;

class MeQrValidator
{
    private AssertService $assertService;
    private ErrorHandlerService $errorHandlerService;

    public function __construct(
        AssertService $assertService,
        ErrorHandlerService $errorHandlerService
    ) {
        $this->assertService = $assertService;
        $this->errorHandlerService = $errorHandlerService;
    }

    public function validate($case): ValidationExceptionList
    {
        if ( is_object($case) ) {
            return $this->assertValidation($case);
        }

        return new ValidationExceptionList();
    }

    private function assertValidation(object $object): ValidationExceptionList
    {
        $properties = $this->assertService->getAllAnnotationPropertiesByObject($object);

        return $this->assertService->validateProperties($properties, $object);
    }

    public function handelExceptionList(ValidationExceptionList $exceptionList): void
    {
        foreach ( $exceptionList->getExceptions() as $exception ) {
            $this->errorHandlerService->writeExceptionToLogs($exception);
        }
    }
}
