<?php

namespace Me_Qr\Services\Woocommerce;

use Me_Qr\Services\QrSave\QrFileManager;
use Me_Qr\Services\Template\TemplateService;

class MeQrWoocommerceService
{
    private TemplateService $templateService;
    private QrFileManager $qrFileManager;

    public function __construct(
        TemplateService $templateService,
        QrFileManager $qrFileManager
    ) {
        $this->templateService = $templateService;
        $this->qrFileManager = $qrFileManager;
    }

    public function registerProductEditorQrMetaBox(): void
    {
        add_action( 'admin_init', function() {
            $isActiveWoocommerce = is_plugin_active('woocommerce/woocommerce.php');
            if ( !$isActiveWoocommerce ) {
                return;
            }

            add_action('add_meta_boxes', function() {
                add_meta_box(
                    'me-qr-code-meta-box',
                    'Qr Code',
                    [$this, 'qrCodeMetaBoxContent'],
                    ['product'],
                    'side',
                    'low',
                );
            });
        } );
    }

    public function qrCodeMetaBoxContent( $post ): void
    {
        $data = [
            'postId' => $post->ID,
            'isQrExist' => $this->qrFileManager->isQrsExists($post->ID)
        ];

        $this->templateService->include('admin/woocommerce/me-qr-wc-meta-box-template', $data);
    }
}
