<?php

use Me_Qr\Foundation\MeQrBaseFunctions;
use Me_Qr\Services\Template\TemplateParams;

return static function( TemplateParams $params ): void
{
    /* Css styles */
    wp_enqueue_style(
        'mq_wc_meta_box_style', MeQrBaseFunctions::getCssUrl('admin/woocommerce/qr-meta-box' )
    );

    $postId = $params->getReq('postId');
    $isQrExist = $params->get('isQrExist');

    ?>
    <div class="me-qr-wc-render-box">
        <div class="me-qr-desc-box">
            <div class="me-qr-desc">
                <?php if ($isQrExist) {
                   echo esc_html('The QR code has already been generated for this product. You can watch it.');
                } else {
                    echo esc_html('Generate a Qr-Code for the current product and use your online store to the fullest.');
                } ?>
            </div>
        </div>

        <div class="me-qr-wc-render-btn-box">
            <button class="me-qr-btn me-qr-wc-render-btn" type="button">
                <?php if ($isQrExist) {
                    echo esc_html('Show Qr-Code');
                } else {
                    echo esc_html('Generate Qr-Code');
                } ?>
            </button>
        </div>
    </div>

    <div class="me-qr-loading-module me-qr-d-none">
        <div class="me-qr-loader"></div>
        <div class="me-qr-loader-text-box">
            <div class="me-qr-loader-text">
                QR code is loading, please wait...
            </div>
        </div>
    </div>

    <div class="me-qr-wc-body me-qr-d-none">
        <div class="me-qr-wc-img-box">
            <img src="" class="me-qr-wc-img" alt="qr_code_img"/>
        </div>

        <div class="me-qr-wc-choice-box">
            <div class="me-qr-wc-choice-item">
                <input type="radio" id="me_qr_svg_radio" name="me_qr_wc_choice_qr_format" value="svg"/>
                <label for="me_qr_svg_radio">svg</label>
            </div>

            <div class="me-qr-wc-choice-item">
                <input type="radio" id="me_qr_wc_png_radio" name="me_qr_wc_choice_qr_format" value="png" checked />
                <label for="me_qr_wc_png_radio">png</label>
            </div>
        </div>

        <div class="me-qr-wc-btn-box">
            <a href="" download="qr_code" class="me-qr-btn me-qr-wc-download-btn">
                Download Qr Code
            </a>
        </div>

        <div class="me-qr-wc-shortcode-box">
            <input type="text" class="me-qr-wc-shortcode-input" value="" />
            <div class="me-qr-wc-shortcode-copy-btn-box">
                <div class="me-qr-wc-shortcode-copy-btn"
                     data-default-text="Copy shortcode"
                     data-success-text="Copied"
                     data-failed-text="Not copied"
                >
                    Copy shortcode
                </div>
            </div>
        </div>
    </div>

    <div class="me-qr-error-box me-qr-d-none">
        <div class="error-header">
            Qr code was not generated.
        </div>
        <div class="error-desc">
            Try reloading the page or reinstalling the plugin
        </div>
    </div>
    <?php

    /* Js scripts */
    wp_enqueue_script(
        'mq_wc_error_module_script',
        MeQrBaseFunctions::getJsUrl('base/modules/ErrorModule')
    );
    wp_enqueue_script(
        'mq_wc_loading_module_script',
        MeQrBaseFunctions::getJsUrl('base/modules/LoadingModule')
    );
    wp_enqueue_script(
        'mq_wc_shortcode_input_script',
        MeQrBaseFunctions::getJsUrl('admin/woocommerce/meta-box/MeQrShortcodeInput')
    );
    wp_enqueue_script(
        'mq_wc_meta_box_script', MeQrBaseFunctions::getJsUrl('admin/woocommerce/meta-box/MeQrMetaBox')
    );
    wp_enqueue_script(
        'mq_wc_meta_box_index_script', MeQrBaseFunctions::getJsUrl('admin/woocommerce/index')
    );
    wp_add_inline_script('mq_wc_meta_box_index_script', "let postId = $postId;", 'before');
};
